@@ -1,4 +1,4 @@
-/* $Id: arith1.c,v 1.246 2006/04/14 15:26:51 kb Exp $
+/* $Id: arith1.c,v 1.246.2.1 2006/09/13 10:24:36 bill Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -731,7 +731,7 @@ ispower(GEN x, GEN K, GEN *pty)
   switch(typ(x)) {
     case t_INT:
       s = signe(x);
-      if (!s) return 1;
+      if (!s) { if (pty) *pty = gen_0; return 1; }
       k = itou(K);
       if (s > 0) {
         if (k == 2) return Z_issquarerem(x, pty);
