@@ -1,4 +1,4 @@
-/* $Id: bibli1.c,v 1.302 2006/04/07 18:00:14 bill Exp $
+/* $Id: bibli1.c,v 1.302.2.1 2006/08/03 17:12:01 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -1326,7 +1326,7 @@ PRECPB:
       {
         if (isexact)
         {
-          if (exact_can_leave) { if (H) h = H; break; }
+          if (exact_can_leave) { if (!in_place && H) h = gmul(H, h); break; }
 
           if (DEBUGLEVEL>3) fprintferr("\nChecking LLL basis...");
           if (!in_place) H = H? gmul(H, h): h;
