@@ -1,4 +1,4 @@
-/* $Id: gen3.c,v 1.239 2006/04/10 07:50:32 kb Exp $
+/* $Id: gen3.c,v 1.239.2.2 2006/10/05 13:06:36 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -835,20 +835,18 @@ GEN
 divrem(GEN x, GEN y, long v)
 {
   pari_sp av = avma;
-  long vx,vy;
-  GEN z,q,r;
+  long vx, vy;
+  GEN q, r;
   if (v < 0 || typ(y) != t_POL || typ(x) != t_POL) return gdiventres(x,y);
   vx = varn(x); if (vx != v) x = swap_vars(x,v);
   vy = varn(y); if (vy != v) y = swap_vars(y,v);
   q = poldivrem(x,y, &r);
   if (v && (vx != v || vy != v))
   {
-    q = poleval(q, pol_x[v]);
-    r = poleval(r, pol_x[v]);
+    q = gsubst(q, v, pol_x[v]); /* poleval broken for t_RFRAC, subst is safe */
+    r = gsubst(r, v, pol_x[v]);
   }
-  z = cgetg(3,t_COL);
-  gel(z,1) = q;
-  gel(z,2) = r; return gerepilecopy(av, z);
+  return gerepilecopy(av, mkcol2(q, r));
 }
 
 static int
@@ -2400,7 +2398,7 @@ _gtoser(GEN x, long v, long prec)
   switch(tx)
   {
     case t_POL:
-      if (varncmp(varn(x), v) <= 0)
+      if (varncmp(varn(x), v) < 0)
         pari_err(talker,"main variable must have higher priority in gtoser");
       y = poltoser(x, v, prec); l = lg(y);
       for (i=2; i<l; i++)
@@ -2408,7 +2406,7 @@ _gtoser(GEN x, long v, long prec)
       break;
 
     case t_RFRAC:
-      if (varncmp(varn(gel(x,2)), v) <= 0)
+      if (varncmp(varn(gel(x,2)), v) < 0)
         pari_err(talker,"main variable must have higher priority in gtoser");
       av = avma;
       return gerepileupto(av, rfractoser(x, v, prec));
