@@ -1,4 +1,4 @@
-/* $Id: polarit1.c,v 1.268 2006/04/11 17:28:55 kb Exp $
+/* $Id: polarit1.c,v 1.268.2.1 2006/08/03 17:21:21 kb Exp $
 
 Copyright (C) 2000-2004  The PARI group.
 
@@ -1264,7 +1264,7 @@ FpX_factor_i(GEN f, GEN pp)
     e *= p; f = poldeflate_i(f2, p);
   }
   setlg(t, nbfact);
-  setlg(E, nbfact); return sort_factor(mkmat2((GEN)t,E), cmpii);
+  setlg(E, nbfact); return sort_factor(mkvec2((GEN)t,E), cmpii);
 }
 GEN
 FpX_factor(GEN f, GEN p)
@@ -2520,7 +2520,7 @@ FqX_factor_i(GEN f, GEN T, GEN p)
       }
   }
   setlg(t, nbfact);
-  setlg(E, nbfact); return sort_factor(mkmat2((GEN)t, E), cmp_pol);
+  setlg(E, nbfact); return sort_factor(mkvec2((GEN)t, E), cmp_pol);
 }
 GEN
 factorff(GEN f, GEN p, GEN T)
