@@ -1,4 +1,4 @@
-/* $Id: trans1.c,v 1.211 2006/04/11 17:28:55 kb Exp $
+/* $Id: trans1.c,v 1.211.2.1 2006/09/30 11:05:52 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -727,9 +727,6 @@ ser_powfrac(GEN x, GEN q, long prec)
   return y;
 }
 
-static GEN padic_sqrt(GEN x);
-GEN padic_sqrtn(GEN x, GEN n, GEN *zetan);
-
 GEN
 gpow(GEN x, GEN n, long prec)
 {
@@ -877,7 +874,7 @@ sqrt_padic(GEN x, GEN modx, long pp, GEN p)
   }
 }
 
-static GEN
+GEN
 padic_sqrt(GEN x)
 {
   long pp, e = valp(x);
