@@ -1,5 +1,5 @@
 #line 2 "../src/kernel/gmp/mp.c"
-/* $Id: mp.c,v 1.87 2005/12/09 18:14:24 kb Exp $
+/* $Id: mp.c,v 1.87.2.1 2006/09/12 13:52:04 bill Exp $
 
 Copyright (C) 2002-2003  The PARI group.
 
@@ -45,12 +45,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 /*We need PARI invmod renamed to invmod_pari*/
 #define INVMOD_PARI
 
+static void *wrap_gprealloc(void *ptr, size_t old_size, size_t new_size) {
+  (void)old_size; return (void *) gprealloc(ptr,new_size);
+}
+
 int pari_kernel_init(void)
 {
   /* Use gpmalloc instead of malloc */
-  mp_set_memory_functions((void *(*)(size_t)) gpmalloc
-		  	,(void *(*)(void *, size_t, size_t)) gprealloc
-		        ,NULL);
+  mp_set_memory_functions((void *(*)(size_t)) gpmalloc, wrap_gprealloc, NULL);
   return 0;
 }
 
